@@ -4,4 +4,4 @@ VERSION = (0, 0, 1)
 
 get_version = lambda: '.'.join(map(str, VERSION))
 
-__all__ = ['base', 'data', 'error', 'github', 'trello']
\ No newline at end of file
+__all__ = ['base', 'data', 'error', 'evaltool', 'github', 'trello']
\ No newline at end of file
