@@ -97,7 +97,7 @@ class GitHubController(controller.CementBaseController):
             raise error.ConfigError("Missing config parameter 'github.auth_id' and/or 'github.auth_token'! "
                                     "Please run 'scrum-tools github authorize' first! ")
 
-        key_id = self.app.config.get('core', 'users_schema_key_id')
+        key_username = self.app.config.get('core', 'users_schema_key_username')
         key_github = self.app.config.get('core', 'users_schema_key_github')
 
         user_repository = data.UserRepository(self.app.config)
@@ -106,10 +106,10 @@ class GitHubController(controller.CementBaseController):
 
         for u in user_repository.users():
             if not u[key_github]:
-                cprint("Skipping empty GitHub account for user '%s'." % u[key_id], 'yellow', file=sys.stdout)
+                cprint("Skipping empty GitHub account for user '%s'." % u[key_username], 'yellow', file=sys.stdout)
                 continue
 
-            print colored("Validating GitHub account '%s' for user '%s'..." % (u[key_github], u[key_id]), 'green'),
+            print colored("Validating GitHub account '%s' for user '%s'..." % (u[key_github], u[key_username]), 'green'),
             try:
                 if gh.user(u[key_github]):
                     print colored('OK', 'green', attrs=['bold'])
@@ -339,8 +339,11 @@ class GitHubController(controller.CementBaseController):
             print colored("Skipping repository '%s' (already exists)." % repo_name, 'yellow')
 
         for team in teams:
-            print "adding repo '%s/%s' to team %s" % (org.login, repo_name, team.name)
-            team.add_repo('%s/%s' % (org.login, repo_name))
+            print colored("Adding repo '%s/%s' to team '%s'..." % (org.login, repo_name, team.name), 'green'),
+            if team.add_repo('%s/%s' % (org.login, repo_name)):
+                print colored('OK', 'green', attrs=['bold'])
+            else:
+                print colored('Not OK', 'red', attrs=['bold'])
 
     @staticmethod
     def __delete_repo(repo_name, repos):
@@ -358,8 +361,7 @@ class GitHubController(controller.CementBaseController):
     def __create_team(org, team_name, repo_names, premission, teams):
         if not team_name in teams:
             print colored("Creating team '%s'..." % team_name, 'green'),
-            team = org.create_team(name=team_name, repo_names=repo_names, permissions=premission)
-            team.edit(team_name, permission=premission)  # bypass a bug in create_team
+            team = org.create_team(name=team_name, repo_names=repo_names, permission=premission)
             if team:
                 teams[team_name] = team
                 print colored('OK', 'green', attrs=['bold'])
@@ -387,7 +389,7 @@ class GitHubController(controller.CementBaseController):
         # add missing team members
         for u in members_exp - members_act:
             print colored("Adding '%s' to team '%s'..." % (u, team.name), 'green'),
-            if team.add_member(u):
+            if team.invite(u):
                 print colored('OK', 'green', attrs=['bold'])
             else:
                 print colored('Not OK', 'red', attrs=['bold'])
